@@ -9,12 +9,17 @@ import os
 import sys
 import time
 
+global silent
+silent = True
+global updated
+updated = 0
+
 # !------------------------------!
 # ! Start                        !
 # !                              !
 # !------------------------------!
 
-__version__ = "1.1.1"
+__version__ = "1.1.3"
 
 
 class CallableModule():
@@ -31,10 +36,17 @@ class CallableModule():
 
 sys.modules[__name__] = CallableModule(sys.modules[__name__])
 
+def allow_update():
+    silent = False
+    if updated == 0:
+        updated = 1
+        checkver()
+
+def not_silent():
+    allow_update()
+
 def online():
     try:
-        # connect to the host -- tells us if the host is actually
-        # reachable
         sock = socket.create_connection(("www.google.com", 80))
         if sock is not None:
             sock.close
@@ -50,9 +62,9 @@ def checkver():
         responseinfl = requests.get(f'https://pypi.org/pypi/{packagenm}/json')
         latest_version = responseinfl.json()['info']['version']
         if latest_version != __version__:
-            print("[{}] New update is here, run 'python3 -m pip install --upgrade input_num' THREE TIMES in normal terminal".format(packagenm))
+            if silent == False:
+                print("[{}] New update is here, run 'python3 -m pip install --upgrade input_num' in normal terminal".format(packagenm))
 
-checkver()
 
 
 def output_num(val):
